@@ -1,8 +1,39 @@
 #!/usr/bin/python
 # coding:utf-8
 #
-# network ping and scan
+# Network ping and scan functions
+# ::
+#     # Net ping and scan examples
 #
+#     from net import Net
+#
+#     # ping a server(or an IP)
+#     t = Net.ping("www.bing.com")  # return milliseconds, return -1 means not available
+#     print('milliseconds', t)
+#
+#     # get IP address of this computer
+#     my_ip = Net.local_ip()
+#
+#     # create an IP range (a list of IP address
+#     ip_list = Net.ip_range(my_ip, 1, 100)
+#     print(ip_list)
+#
+#     # Scan the IPs, return list of pingable IPs
+#     exists_ips = Net.ip_scan(ip_list)
+#     print(exists_ips)
+#
+#     # whether a port of specified IP is opened
+#     if Net.is_port_open(my_ip, 80):
+#         print('port 80 of', my_ip, 'opened')
+#     else:
+#         print('port 80 of', my_ip, 'not opened')
+#
+#
+#     # scan a list of port on specified IP address, return opened port list
+#     port_list = Net.port_scan(my_ip, [80, 8080, 21, 22, 443, 445])
+#     print('opened ports', port_list)
+#
+
 
 import socket
 import platform
@@ -15,7 +46,7 @@ from .util import rprint, StrUtil
 from .http import Http
 
 
-# A task for scan
+# Internal use：A task for scan
 class _ScanTask:
     """
     A task for scan
@@ -165,7 +196,7 @@ def _port_scan_thread(task, start, end):
         task.finish_one()  # 完成一个
 
 
-# Network ping and scan
+# Network ping and scan functions
 class Net:
     """
     Network ping and scan
@@ -342,7 +373,7 @@ class Net:
     def get_connection_ip(host, port):
         """
         Get the local IP address that connects to the specified host.
-        
+
         :Chinese: 取得可连接到指定服务器的本地IP地址.
 
         :param host:  host domain or ip
@@ -619,20 +650,21 @@ class Net:
         return task.result
 
     @staticmethod
-    def is_port_open(ip, port, udp=False):
+    def is_port_open(ip, port, udp=False, timeout=2000):
         """
         Whether specified port is opened on specified IP address.
 
-        :Chinese: 判断服务器的指定端口是否开放.
+        :Chinese: 判断 指定IP地址的指定端口是否开放.
 
         :param ip:    the IP address or host name
         :param port:  port number, int
-        :param udp:   (optional) whether use UDP. default is False
+        :param udp:   (optional) whether UDP protocol is used. default is False
+        :param timeout:   (optional) timeout in milliseconds. default is 2000
         :return: return True if the port is opened. return False if not opened.
         """
         family = socket.SOCK_DGRAM if udp else socket.SOCK_STREAM
         sock = socket.socket(socket.AF_INET, family)
-        sock.settimeout(2000)
+        sock.settimeout(timeout)
 
         if not isinstance(port, int):
             port = int(port)
@@ -658,7 +690,7 @@ class Net:
         :param exists:   (optional) Whether return opened ports. If exists is False, return not-opened ports.
                 :Chinese:（可选）是否取得可连接的端口，默认值是True.<br>
                 如果exists=False,则结果列表是不可连接的端口。<br>
-        :param threads:  (optional) how many threads that uses. default is 0 for auto detect.
+        :param threads:  (optional) how many threads that uses. default 0 is auto-detect.
                     :Chinese:（可选）并发线程数量，默认值是0(自动选择线程数量）
         :param name:    (optional) whether return the protocol name.
                         If name is True, each item of result list is a tuple of (port, protocol).
@@ -722,6 +754,7 @@ class Net:
 
 # noinspection PyPep8Naming
 # noinspection SpellCheckingInspection
+# Common used port
 class Port:
     """ common used port """
 
@@ -824,4 +857,3 @@ class Port:
             if Port.__dict__[name] == port_number:
                 return name
         return ''
-
