@@ -178,38 +178,42 @@ class StrUtil:
         return offset >= 0
 
     @staticmethod
-    def get_word(text, before, after, start_offset=0, return_offset=False):
+    def get_word(text, before, after, begin=0, return_offset=False):
         """
         Get a word from text, the word is between before condition, and after condition.
 
         :Chinese: 从文本中提取一个词，该词在查找条件before后, 查找条件after前
 
         :param text:    the string
-        :param before:  the before condition, could be a sub string or a list of string.<br>
-                :Chinese: 查找条件before
-        :param after:   the end condition, could be a sub string or a list of string.<br>
+        :param before:   the texts which is before the finding word, could be a string or a list of string.<br>
+                :Chinese: 查找在 after 之后的词
+        :param after:   the texts which is after the finding word,, could be a sub string or a list of string.<br>
                 :Chinese: 查找条件end
-        :param start_offset:    offset to start finding.
+        :param begin:    offset to start finding.
                 :Chinese:（可选）开始查找的位置
         :param return_offset:  whether return offset, boolean.
                 :Chinese:（可选）是否返回查找后的位置
         :return: return str if found, return None if not found.
+                if return_offset is True, return a tuple of (str, offset_int)
                 :Chinese: 返回一个词。 如果找不到，返回None
         """
-        if start_offset is not None and not isinstance(start_offset, int):
-            offset, length = StrUtil.match_offset_length(text, str(start_offset), 0)
+        if begin is None:
+            begin = 0
+
+        if begin is not None and not isinstance(begin, int):
+            offset, length = StrUtil.match_offset_length(text, str(begin), 0)
             if offset < 0:
-                return None
+                return None, None if return_offset else None
             else:
-                start_offset = offset + length
+                begin = offset + length
 
-        if start_offset < 0:
+        if begin < 0:
             if return_offset:
-                return None, start_offset
+                return None, begin
             else:
                 return None
 
-        b, len1 = StrUtil.match_offset_length(text, before, start_offset)
+        b, len1 = StrUtil.match_offset_length(text, before, begin)
         if b > 0:
             e, len2 = StrUtil.match_offset_length(text, after, b + len1)
             if e > b + len1:
@@ -219,12 +223,12 @@ class StrUtil:
                     return text[b + len1: e]
         else:
             if return_offset:
-                return None, start_offset
+                return None, begin
             else:
                 return None
 
     @staticmethod
-    def get_word_list(text, begin, betweens, start_offset=0, end=None):
+    def get_word_list(text, begin, betweens, end=None, start_offset=0):
         """
         get a list of keywords from the text.
 
@@ -247,8 +251,8 @@ class StrUtil:
                          每一个元素单词定义, 一个 2个元素tuple, 第0个元素是before条件，
                          第1个元素是after条件.
 
-        :param start_offset: (optional) offset to start finding
         :param end:  (optional) end condition, could be a sub string or a list of string.<br>
+        :param start_offset: (optional) offset to start finding
         :return:  return a list of words
         """
         result = []
